@@ -5,7 +5,7 @@ use bigint;
 use Carp;
 use Pegex::Base; # use this instead of Mo
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 $VERSION = eval $VERSION;
 
 has type => 'gpsim';
@@ -33,9 +33,10 @@ sub supports_modifier {
 
 sub init_code {
     my $self = shift;
+    croak "This chip is not supported" unless $self->pic->doesroles(qw(Chip CodeGen GPIO));
     my $pic = '';
     $pic = $self->pic->type if $self->pic;
-    my $freq = $self->pic->frequency if $self->pic;
+    my $freq = $self->pic->f_osc if $self->pic;
     if ($freq) {
         $freq = qq{\t.sim "$pic.frequency = $freq"};
     } else {
@@ -66,19 +67,38 @@ sub _gen_led {
 ...
 }
 
+
+sub _get_gpio_info {
+    my ($self, $port) = @_;
+    my $gpio_pin = $self->pic->get_input_pin($port);
+    if ($gpio_pin) {
+        # this is a pin
+        return @{$self->pic->input_pins->{$gpio_pin}};
+    } else {
+        $gpio_pin = $self->pic->get_output_pin($port);
+        if ($gpio_pin) {
+            # this is a pin
+            return @{$self->pic->output_pins->{$gpio_pin}};
+        }
+    }
+    return;
+}
+
 sub _get_simreg {
     my ($self, $port) = @_;
     my $simreg = lc $port;
     if ($self->pic) {
-        my $vport = $self->pic->convert_to_valid_pin($port);
-        $port = $vport if defined $vport;
-        if (exists $self->pic->ports->{$port}) {
+        if (exists $self->pic->registers->{$port}) {
             # this is a port
             $simreg = lc $port;
         } elsif (exists $self->pic->pins->{$port}) {
-            # this is a pin
-            my ($p1, $p2, $p3) = @{$self->pic->pins->{$port}};
-            $simreg = lc "PORT$p1";
+            my ($io1) = $self->_get_gpio_info($port);
+            if (defined $io1) {
+                $simreg = lc $io1;
+            } else {
+                my $pic = $self->pic->type;
+                carp "Cannot find '$port' in PIC $pic. Using '$simreg'";
+            }
         } else {
             my $pic = $self->pic->type;
             carp "Cannot find '$port' in PIC $pic. Using '$simreg'";
@@ -91,17 +111,18 @@ sub _get_simport {
     my ($self, $port, $pin) = @_;
     my $simport = lc $port;
     if ($self->pic) {
-        my $vport = $self->pic->convert_to_valid_pin($port);
-        $port = $vport if defined $vport;
-        if (exists $self->pic->ports->{$port}) {
+        if (exists $self->pic->registers->{$port}) {
             # this is a port
-            my $p1 = $self->pic->ports->{$port};
-            $simport = lc "PORT$p1";
+            $simport = lc $port;
             $simport .= $pin if defined $pin;
         } elsif (exists $self->pic->pins->{$port}) {
-            # this is a pin
-            my ($p1, $p2, $p3) = @{$self->pic->pins->{$port}};
-            $simport = lc "PORT$p1$p2";
+            my ($io1, $io2, $io3) = $self->_get_gpio_info($port);
+            if (defined $io1 and defined $io3) {
+                $simport = lc "$io1$io3";
+            } else {
+                my $pic = $self->pic->type;
+                carp "Cannot find '$port' in PIC $pic. Using '$simport'";
+            }
         } else {
             my $pic = $self->pic->type;
             carp "Cannot find '$port' in PIC $pic. Using '$simport'";
@@ -115,17 +136,18 @@ sub _get_portpin {
     my $simport = lc $port;
     my $simpin;
     if ($self->pic) {
-        my $vport = $self->pic->convert_to_valid_pin($port);
-        $port = $vport if defined $vport;
-        if (exists $self->pic->ports->{$port}) {
+        if (exists $self->pic->registers->{$port}) {
             # this is a port
-            my $p1 = $self->pic->ports->{$port};
-            $simport = lc "PORT$p1";
+            $simport = lc $port;
         } elsif (exists $self->pic->pins->{$port}) {
-            # this is a pin
-            my ($p1, $p2, $p3) = @{$self->pic->pins->{$port}};
-            $simport = lc "PORT$p1";
-            $simpin = $p2;
+            my ($io1, $io2, $io3) = $self->_get_gpio_info($port);
+            if (defined $io1) {
+                $simport = lc $io1;
+                $simpin = $io3;
+            } else {
+                my $pic = $self->pic->type;
+                carp "Cannot find '$port' in PIC $pic. Using '$simport'";
+            }
         } else {
             return;
         }
@@ -172,11 +194,11 @@ sub attach_led7seg {
     foreach my $p (@pins) {
         if (exists $self->pic->pins->{$p}) {
             push @simpins, $p;
-        } elsif (exists $self->pic->ports->{$p}) {
-            my $port = $self->pic->ports->{$p};
-            foreach (sort(keys %{$self->pic->pins})) {
-                next unless defined $self->pic->pins->{$_}->[0];
-                push @simpins, $_ if $self->pic->pins->{$_}->[0] eq $port;
+        } elsif (exists $self->pic->registers->{$p}) {
+            # find all the output pins for the port
+            foreach (sort(keys %{$self->pic->output_pins})) {
+                next unless defined $self->pic->output_pins->{$_}->[0];
+                push @simpins, $_ if $self->pic->output_pins->{$_}->[0] eq $p;
             }
         } elsif ($p =~ /red|orange|green|yellow|blue/i) {
             $color = $p;
